
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#pragma once

            #include <glib-object.h>


            G_BEGIN_DECLS

/* enumerations from "ovirt-disk.h" */


GType ovirt_disk_content_type_get_type (void);
#define OVIRT_TYPE_DISK_CONTENT_TYPE (ovirt_disk_content_type_get_type())

/* enumerations from "ovirt-error.h" */


GType ovirt_error_get_type (void);
#define OVIRT_TYPE_ERROR (ovirt_error_get_type())

/* enumerations from "ovirt-rest-call-error.h" */


GType ovirt_rest_call_error_get_type (void);
#define OVIRT_TYPE_REST_CALL_ERROR (ovirt_rest_call_error_get_type())

/* enumerations from "ovirt-storage-domain.h" */


GType ovirt_storage_domain_format_version_get_type (void);
#define OVIRT_TYPE_STORAGE_DOMAIN_FORMAT_VERSION (ovirt_storage_domain_format_version_get_type())


GType ovirt_storage_domain_state_get_type (void);
#define OVIRT_TYPE_STORAGE_DOMAIN_STATE (ovirt_storage_domain_state_get_type())


GType ovirt_storage_domain_type_get_type (void);
#define OVIRT_TYPE_STORAGE_DOMAIN_TYPE (ovirt_storage_domain_type_get_type())


GType ovirt_storage_domain_storage_type_get_type (void);
#define OVIRT_TYPE_STORAGE_DOMAIN_STORAGE_TYPE (ovirt_storage_domain_storage_type_get_type())

/* enumerations from "ovirt-vm-display.h" */


GType ovirt_vm_display_type_get_type (void);
#define OVIRT_TYPE_VM_DISPLAY_TYPE (ovirt_vm_display_type_get_type())

/* enumerations from "ovirt-vm.h" */


GType ovirt_vm_state_get_type (void);
#define OVIRT_TYPE_VM_STATE (ovirt_vm_state_get_type())

G_END_DECLS

/* Generated data ends here */

